@@ -12,11 +12,22 @@ class ApplicationController < ActionController::Base
   filter_parameter_logging :password
 
   before_filter :set_timezone
+  before_filter :set_autorefresh
 
   private
 
+  def set_autorefresh
+    if params[:autorefresh]
+      if params[:autorefresh] == "true"
+        session[:autorefresh] = true
+      else
+        session.delete(:autorefresh)
+      end
+    end
+  end
+
   def raise_if_enable_read_only_mode
-    raise ReadOnlyEnabledError.new if SETTINGS.enable_read_only_mode
+    raise ReadOnlyEnabledError.new if SETTINGS.enable_read_only_mode || session['ACCESS_CONTROL_ROLE'] == 'READ_ONLY'
   end
 
   def raise_unless_using_external_node_classification
