@@ -1,7 +1,7 @@
 require 'puppet_https'
 
 class Node < ActiveRecord::Base
-  def self.per_page; 20 end # Pagination
+  def self.per_page; SETTINGS.nodes_per_page end # Pagination
 
   include NodeGroupGraph
   extend FindFromForm
@@ -14,7 +14,7 @@ class Node < ActiveRecord::Base
   has_many :node_classes, :through => :node_class_memberships
   has_many :node_group_memberships, :dependent => :destroy
   has_many :node_groups, :through => :node_group_memberships
-  has_many :reports
+  has_many :reports, :dependent => :destroy
   has_many :resource_statuses, :through => :reports
 
   belongs_to :last_apply_report, :class_name => 'Report'
