@@ -1,4 +1,9 @@
+require 'trimmer'
+
 class Parameter < ActiveRecord::Base
+  include Trimmer
+  trimmed_fields :key
+
   belongs_to :parameterable, :polymorphic => true
   validates_presence_of :key
 
