@@ -28,7 +28,12 @@ ActionController::Routing::Routes.draw do |map|
 
   map.resources :reports,
     :collection => {
-      :search => :get,
+      :search    => :get,
+      :all       => :get,
+      :failed    => :get,
+      :pending   => :get,
+      :changed   => :get,
+      :unchanged => :get
     }
 
   map.resources :node_group_memberships, :as => :memberships
@@ -40,6 +45,8 @@ ActionController::Routing::Routes.draw do |map|
   map.header '/header.:format', :controller => :pages, :action => :header
 
   map.root :controller => :pages, :action => :home
+  
+  map.connect 'radiator', :controller => :radiator, :action => :index
 
   map.connect ':controller/:action/:id'
   map.connect ':controller/:action/:id.:format'
