@@ -154,14 +154,21 @@ describe Node do
     end
 
     it 'should return a name and set of classes and parameters' do
-      @node.configuration.keys.sort.should == ['classes', 'name', 'parameters']
+      @node.configuration.keys.should =~ ['classes', 'name', 'parameters']
     end
 
+#This won't work any more once class parameters are introduced
     it "should return the names of the node's classes in the returned class list" do
       @node.node_classes = @classes = Array.new(3) { NodeClass.generate! }
-      @node.configuration['classes'].sort.should == @classes.collect(&:name).sort
+      @node.configuration['classes'].should =~ @classes.collect(&:name)
     end
 
+#This will replace the previous test once class parameters are introduced
+#    it "should return the names of the node's classes in the keys of the returned class list" do
+#      @node.node_classes = @classes = Array.new(3) { NodeClass.generate! }
+#      @node.configuration['classes'].keys.should =~ @classes.collect(&:name)
+#    end
+
     it "should return the node's compiled parameters in the returned parameters list" do
       @node.stubs(:compiled_parameters).returns [
         OpenStruct.new(:name => 'a', :value => 'b', :sources => Set[:foo]),
@@ -232,7 +239,7 @@ describe Node do
     describe "handling parameters in the graph" do
 
       it "should return the compiled parameters" do
-        @node.compiled_parameters.should == [
+        @node.compiled_parameters.should =~ [
           OpenStruct.new(:name => 'foo', :value => '1', :sources => Set[@node_group_a]),
           OpenStruct.new(:name => 'bar', :value => '2', :sources => Set[@node_group_b])
         ]
@@ -243,7 +250,7 @@ describe Node do
         @node_group_a1.parameters << Parameter.create(:key => 'foo', :value => '2')
         @node_group_a.node_groups << @node_group_a1
 
-        @node.compiled_parameters.should == [
+        @node.compiled_parameters.should =~ [
           OpenStruct.new(:name => 'foo', :value => '1', :sources => Set[@node_group_a]),
           OpenStruct.new(:name => 'bar', :value => '2', :sources => Set[@node_group_b])
         ]
@@ -264,12 +271,12 @@ describe Node do
       end
 
       it "should not raise an error if there are parameter conflicts that can be resolved at a higher level" do
-        @param_3 = Parameter.generate(:key => 'foo', :value => '3')
-        @param_4 = Parameter.generate(:key => 'foo', :value => '4')
+        param_3 = Parameter.generate(:key => 'foo', :value => '3')
+        param_4 = Parameter.generate(:key => 'foo', :value => '4')
         @node_group_c = NodeGroup.generate!
-        @node_group_c.parameters << @param_3
+        @node_group_c.parameters << param_3
         @node_group_d = NodeGroup.generate!
-        @node_group_d.parameters << @param_4
+        @node_group_d.parameters << param_4
         @node_group_a.node_groups << @node_group_c << @node_group_d
 
         lambda {@node.compiled_parameters}.should_not raise_error(ParameterConflictError)
@@ -279,8 +286,7 @@ describe Node do
       it "should include parameters of the node itself" do
         @node.parameters << Parameter.create(:key => "node_parameter", :value => "exist")
 
-        @node.compiled_parameters.first.name.should == "node_parameter"
-        @node.compiled_parameters.first.value.should == "exist"
+        @node.compiled_parameters.should be_any {|p| p.name == "node_parameter" && p.value == "exist"}
       end
 
       it "should retain the history of its parameters" do
@@ -291,7 +297,7 @@ describe Node do
         @node_group_a.node_groups << @node_group_c
         @node_group_a.node_groups << @node_group_d
 
-        @node.compiled_parameters.should == [
+        @node.compiled_parameters.should =~ [
           OpenStruct.new(:name => 'foo', :value => '1', :sources => Set[@node_group_a]),
           OpenStruct.new(:name => 'bar', :value => '2', :sources => Set[@node_group_b])
         ]
